Changelog
=========

1.0a1 (2016-02-14)
------------------

- Add Plone integration.
  [thet]

- Restructure as preparation for adding Plone integration code.
  [thet]

- Adapt to new mockup/patternslib changes.
  [thet]
